###

###

##

###

###

    		Prospectus

    			This is a module for organizing.

    		on
    			session 1
    				docker compose up -d; docker exec -it prosthetic.1 bash -c "bash"
    				. /habitat/_controls/build_1.sh

    			session 2
    				 docker exec -it prosthetic.1 bash -c "bash"
    				. /habitat/_controls/build_2.sh

    		#
    		#
    		#	Frontend: Build
    		#
    		#		Locations of build:
    		#			package.json
    		#			svelte.config.js
    		#
    		#
    		# (cd /habitat/parties_frontend/sveltenetics && pnpm run build_frontend)

    		docker container stop prosthetic.1; docker container remove prosthetic.1

    		(cd /habitat/constellations && prosthetic_1 ventures on)
    		(cd /habitat/parties_frontend/sveltenetics && pnpm run dev)

    		#
    		#	localStorage.setItem ("origin_address", "http://192.168.0.98:22000")
    		#
    		#

    		#
    		# 	[mongo] 192.168.0.98:39000
    		#	[sanic] 192.168.0.98:22000
    		#

    		unfinished:
    			prosthetic_1 trends move_to_treasures --domain "garbage.2"

    			prosthetic_1 treasures pass --domain "garbage.3"

    	monetary
    		objectives:
    			[ ] export the "passes", dump the "squeezes"

    		saving
    			prosthetic_1 adventures monetary saves export --version 1

    		loading
    			prosthetic_1 adventures monetary saves import --version 1 --drop